@@ -3,7 +3,7 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
+ *  the Free Software Foundation; either version 3, or (at your option)
  *  any later version.
  *
  *  This program is distributed in the hope print_operation it will be useful,
@@ -12,8 +12,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -275,9 +274,7 @@ gucharmap_print_operation_custom_widget_apply (GtkPrintOperation *operation,
 static void
 gucharmap_print_operation_init (GucharmapPrintOperation *print_operation)
 {
-  GucharmapPrintOperationPrivate *priv;
-
-  priv = print_operation->priv = GUCHARMAP_PRINT_OPERATION_GET_PRIVATE (print_operation);
+  print_operation->priv = GUCHARMAP_PRINT_OPERATION_GET_PRIVATE (print_operation);
 }
 
 static GObject *
